@@ -13,7 +13,10 @@ __title__ = 'github3'
 __author__ = 'Ian Cordasco'
 __license__ = 'Modified BSD'
 __copyright__ = 'Copyright 2012 Ian Cordasco'
-__version__ = '0.1a'
+__version__ = '0.2'
 
-from .api import *
-from .github import GitHub
+from github3.api import *
+from github3.github import GitHub
+from github3.models import GitHubError
+
+# flake8: noqa
